@@ -1,19 +1,19 @@
-//============================================================================
-// Copyright 2009- ECMWF.
-// This software is licensed under the terms of the Apache Licence version 2.0
-// which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
-// In applying this licence, ECMWF does not waive the privileges and immunities
-// granted to it by virtue of its status as an intergovernmental organisation
-// nor does it submit to any jurisdiction.
-//
-//============================================================================
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
 
-#ifndef ASTCOLLATEVNODESVISITOR_HPP
-#define ASTCOLLATEVNODESVISITOR_HPP
+#ifndef ecflow_viewer_AstCollateVNodeVisitor_HPP
+#define ecflow_viewer_AstCollateVNodeVisitor_HPP
 
 #include <vector>
 
-#include "ExprAstVisitor.hpp"
+#include "ecflow/node/ExprAstVisitor.hpp"
 
 class VItem;
 
@@ -40,6 +40,7 @@ public:
     void visitLessThan(AstLessThan*) override {}
     void visitLeaf(AstLeaf*) override {}
     void visitInteger(AstInteger*) override {}
+    void visitInstant(AstInstant*) override {}
     void visitFunction(AstFunction*) override {}
     void visitNodeState(AstNodeState*) override {}
     void visitEventState(AstEventState*) override;
@@ -52,4 +53,4 @@ private:
     std::vector<VItem*>& items_;
 };
 
-#endif // ASTCOLLATEVNODESVISITOR_HPP
+#endif /* ecflow_viewer_AstCollateVNodeVisitor_HPP */
