@@ -1,15 +1,15 @@
-//============================================================================
-// Copyright 2009- ECMWF.
-// This software is licensed under the terms of the Apache Licence version 2.0
-// which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
-// In applying this licence, ECMWF does not waive the privileges and immunities
-// granted to it by virtue of its status as an intergovernmental organisation
-// nor does it submit to any jurisdiction.
-//
-//============================================================================
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
 
-#ifndef SERVERLISTSYNCWIDGET_HPP
-#define SERVERLISTSYNCWIDGET_HPP
+#ifndef ecflow_viewer_ServerListSyncWidget_HPP
+#define ecflow_viewer_ServerListSyncWidget_HPP
 
 #include <vector>
 
@@ -24,7 +24,7 @@ class ServerListSyncWidget : public QWidget, protected Ui::ServerListSyncWidget
     Q_OBJECT
 
 public:
-    ServerListSyncWidget(QWidget* parent = nullptr);
+    explicit ServerListSyncWidget(QWidget* parent = nullptr);
     ~ServerListSyncWidget() override;
     void reload();
 
@@ -40,4 +40,4 @@ private:
     QString buildTable(QString name, QString host, QString port) const;
 };
 
-#endif // SERVERLISTSYNCWIDGET_HPP
+#endif /* ecflow_viewer_ServerListSyncWidget_HPP */
