@@ -1,14 +1,15 @@
-//============================================================================
-// Copyright 2009- ECMWF.
-// This software is licensed under the terms of the Apache Licence version 2.0
-// which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
-// In applying this licence, ECMWF does not waive the privileges and immunities
-// granted to it by virtue of its status as an intergovernmental organisation
-// nor does it submit to any jurisdiction.
-//============================================================================
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
 
-#ifndef TIMELINEMODEL_CPP
-#define TIMELINEMODEL_CPP
+#ifndef ecflow_viewer_TimelineModel_HPP
+#define ecflow_viewer_TimelineModel_HPP
 
 #include <QAbstractItemModel>
 #include <QDateTime>
@@ -79,7 +80,7 @@ class TimelineSortModel : public QSortFilterProxyModel {
     Q_OBJECT
 
 public:
-    TimelineSortModel(TimelineModel*, QObject* parent = nullptr);
+    explicit TimelineSortModel(TimelineModel*, QObject* parent = nullptr);
     ~TimelineSortModel() override;
 
     enum SortMode { PathSortMode, TimeSortMode, TreeSortMode, QtSortMode };
@@ -128,4 +129,4 @@ protected:
     QString rootNodeFilter_;
 };
 
-#endif // TIMELINEMODEL_CPP
+#endif // ecflow_viewer_TimelineModel_HPP
