@@ -1,15 +1,15 @@
-//============================================================================
-// Copyright 2009- ECMWF.
-// This software is licensed under the terms of the Apache Licence version 2.0
-// which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
-// In applying this licence, ECMWF does not waive the privileges and immunities
-// granted to it by virtue of its status as an intergovernmental organisation
-// nor does it submit to any jurisdiction.
-//
-//============================================================================
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
 
-#ifndef TIMELINEVIEW_HPP
-#define TIMELINEVIEW_HPP
+#ifndef ecflow_viewer_TimelineView_HPP
+#define ecflow_viewer_TimelineView_HPP
 
 #include <QAction>
 #include <QDateTime>
@@ -166,4 +166,4 @@ protected:
     bool useMeanDuration_{false};
 };
 
-#endif // TIMELINEVIEW_HPP
+#endif /* ecflow_viewer_TimelineView_HPP */
