@@ -1,24 +1,24 @@
-//============================================================================
-// Copyright 2009- ECMWF.
-// This software is licensed under the terms of the Apache Licence version 2.0
-// which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
-// In applying this licence, ECMWF does not waive the privileges and immunities
-// granted to it by virtue of its status as an intergovernmental organisation
-// nor does it submit to any jurisdiction.
-//
-//============================================================================
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
 
-#ifndef VAUTOCANCELATTR_HPP
-#define VAUTOCANCELATTR_HPP
+#ifndef ecflow_viewer_VAutoCancelAttr_HPP
+#define ecflow_viewer_VAutoCancelAttr_HPP
 
 #include <string>
 #include <vector>
 
 #include <QStringList>
 
-#include "AutoCancelAttr.hpp"
 #include "VAttribute.hpp"
 #include "VAttributeType.hpp"
+#include "ecflow/attribute/AutoCancelAttr.hpp"
 
 class AttributeFilter;
 class VAttributeType;
@@ -38,7 +38,7 @@ private:
 class VAutoCancelAttr : public VAttribute {
 
 public:
-    VAutoCancelAttr(VNode* parent);
+    explicit VAutoCancelAttr(VNode* parent);
 
     VAttributeType* type() const override;
     QStringList data(bool firstLine) const override;
@@ -46,4 +46,4 @@ public:
     static void scan(VNode* vnode, std::vector<VAttribute*>& vec);
 };
 
-#endif // VAUTOCANCELATTR_HPP
+#endif /* ecflow_viewer_VAutoCancelAttr_HPP */
