@@ -1,14 +1,15 @@
-//============================================================================
-// Copyright 2009- ECMWF.
-// This software is licensed under the terms of the Apache Licence version 2.0
-// which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
-// In applying this licence, ECMWF does not waive the privileges and immunities
-// granted to it by virtue of its status as an intergovernmental organisation
-// nor does it submit to any jurisdiction.
-//============================================================================
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
 
-#ifndef VIEWFILTER_HPP_
-#define VIEWFILTER_HPP_
+#ifndef ecflow_viewer_VFilter_HPP
+#define ecflow_viewer_VFilter_HPP
 
 #include <set>
 #include <vector>
@@ -16,9 +17,9 @@
 #include <QObject>
 #include <QStringList>
 
-#include "Node.hpp"
 #include "VInfo.hpp"
 #include "VParam.hpp"
+#include "ecflow/node/Node.hpp"
 
 class NodeQuery;
 class NodeFilterEngine;
@@ -210,4 +211,4 @@ private:
     int matchCount_;
 };
 
-#endif
+#endif /* ecflow_viewer_VFilter_HPP */
