@@ -1,14 +1,24 @@
-#ifndef VLATE_HPP
-#define VLATE_HPP
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_viewer_VLateAttr_HPP
+#define ecflow_viewer_VLateAttr_HPP
 
 #include <string>
 #include <vector>
 
 #include <QStringList>
 
-#include "LateAttr.hpp"
 #include "VAttribute.hpp"
 #include "VAttributeType.hpp"
+#include "ecflow/attribute/LateAttr.hpp"
 
 class AttributeFilter;
 class VAttributeType;
@@ -37,4 +47,4 @@ public:
     static void scan(VNode* vnode, std::vector<VAttribute*>& vec);
 };
 
-#endif // VLATE_HPP
+#endif /* ecflow_viewer_VLateAttr_HPP */
