@@ -32,8 +32,9 @@ QString VUserVarAttrType::toolTip(QStringList d) const {
     if (d.count() == dataCount_) {
         t += "<b>Name:</b> " + d[NameIndex] + "<br>";
         QString s = d[ValueIndex];
-        if (s.size() > 150)
+        if (s.size() > 150) {
             s = s.left(150) + "...";
+        }
         t += "<b>Value:</b> " + s;
     }
     return t;
