@@ -16,6 +16,7 @@
 #include "ecflow/core/Serialization.hpp"
 #include "ecflow/node/Memento.hpp"
 #include "ecflow/node/Node.hpp"
+#include "formatter/DefsWriter.hpp"
 
 #ifdef DEBUG
     #include <iostream>
@@ -64,21 +65,6 @@ void MiscAttrs::requeue() {
     }
 }
 
-void MiscAttrs::print(std::string& os) const {
-    for (const ZombieAttr& z : zombies_) {
-        z.print(os);
-    }
-    for (const VerifyAttr& v : verifys_) {
-        v.print(os);
-    }
-    for (const QueueAttr& q : queues_) {
-        q.print(os);
-    }
-    for (const GenericAttr& g : generics_) {
-        g.print(os);
-    }
-}
-
 bool MiscAttrs::operator==(const MiscAttrs& rhs) const {
     if (zombies_.size() != rhs.zombies_.size()) {
 #ifdef DEBUG
