@@ -27,10 +27,10 @@ import glob
 # o Make sure origin file, has the right permissions
 # o Copy file to different directory, and change the permissions
 #   since file(COPY) does rename files
-#   configure_file(setup.py.in /tmp/ecflow-packaging-stage.1l0fbCiRi7/ecflow-build-sandbox/CMakeFiles/setup.py)
+#   configure_file(setup.py.in /tmp/ecflow-packaging-stage.TMI7sHUj3L/ecflow-build-sandbox/CMakeFiles/setup.py)
 #       now copy the temporary into the final destination, setting the permissions
-#   file(COPY /tmp/ecflow-packaging-stage.1l0fbCiRi7/ecflow-build-sandbox/CMakeFiles/setup.py
-#     DESTINATION /tmp/ecflow-packaging-stage.1l0fbCiRi7/ecflow-build-sandbox
+#   file(COPY /tmp/ecflow-packaging-stage.TMI7sHUj3L/ecflow-build-sandbox/CMakeFiles/setup.py
+#     DESTINATION /tmp/ecflow-packaging-stage.TMI7sHUj3L/ecflow-build-sandbox
 #     FILE_PERMISSIONS OWNER_READ OWNER_WRITE OWNER_EXECUTE GROUP_READ
 #     GROUP_EXECUTE WORLD_READ WORLD_EXECUTE)
 # ============================================================================
@@ -40,29 +40,29 @@ import glob
 # to get this to work, you will need to include the path
 # to your boost installation and  ecflow includes
 boost_root=os.getenv("BOOST_ROOT") 
-include_dirs = [ "/tmp/ecflow-packaging-stage.1l0fbCiRi7/ecflow/libs/pyext/../3rdparty/cereal/include",
-                 "/tmp/ecflow-packaging-stage.1l0fbCiRi7/ecflow/libs/pyext/../libs/core/src",
-                 "/tmp/ecflow-packaging-stage.1l0fbCiRi7/ecflow/libs/pyext/../libs/attribute/src",
-                 "/tmp/ecflow-packaging-stage.1l0fbCiRi7/ecflow/libs/pyext/../libs/node/parser/src",
-                 "/tmp/ecflow-packaging-stage.1l0fbCiRi7/ecflow/libs/pyext/../libs/node/src",
-                 "/tmp/ecflow-packaging-stage.1l0fbCiRi7/ecflow/libs/pyext/../libs/base/src",
-                 "/tmp/ecflow-packaging-stage.1l0fbCiRi7/ecflow/libs/pyext/../libs/base/src/cts",
-                 "/tmp/ecflow-packaging-stage.1l0fbCiRi7/ecflow/libs/pyext/../libs/base/src/stc",
-                 "/tmp/ecflow-packaging-stage.1l0fbCiRi7/ecflow/libs/pyext/../libs/simulator/src",
-                 "/tmp/ecflow-packaging-stage.1l0fbCiRi7/ecflow/libs/pyext/../libs/client/src",
-                 "/tmp/ecflow-packaging-stage.1l0fbCiRi7/ecflow/libs/pyext/src",
+include_dirs = [ "/tmp/ecflow-packaging-stage.TMI7sHUj3L/ecflow/libs/pyext/../3rdparty/cereal/include",
+                 "/tmp/ecflow-packaging-stage.TMI7sHUj3L/ecflow/libs/pyext/../libs/core/src",
+                 "/tmp/ecflow-packaging-stage.TMI7sHUj3L/ecflow/libs/pyext/../libs/attribute/src",
+                 "/tmp/ecflow-packaging-stage.TMI7sHUj3L/ecflow/libs/pyext/../libs/node/parser/src",
+                 "/tmp/ecflow-packaging-stage.TMI7sHUj3L/ecflow/libs/pyext/../libs/node/src",
+                 "/tmp/ecflow-packaging-stage.TMI7sHUj3L/ecflow/libs/pyext/../libs/base/src",
+                 "/tmp/ecflow-packaging-stage.TMI7sHUj3L/ecflow/libs/pyext/../libs/base/src/cts",
+                 "/tmp/ecflow-packaging-stage.TMI7sHUj3L/ecflow/libs/pyext/../libs/base/src/stc",
+                 "/tmp/ecflow-packaging-stage.TMI7sHUj3L/ecflow/libs/pyext/../libs/simulator/src",
+                 "/tmp/ecflow-packaging-stage.TMI7sHUj3L/ecflow/libs/pyext/../libs/client/src",
+                 "/tmp/ecflow-packaging-stage.TMI7sHUj3L/ecflow/libs/pyext/src",
                  boost_root,
                ]
 
 # define the library directories to include any extra libraries that may be needed.
 # Give preference to release libs   
 boost_lib_dir = boost_root + "/stage/lib/"
-library_dirs = ['/tmp/ecflow-packaging-stage.1l0fbCiRi7/ecflow-build-sandbox/libs/core',
-                '/tmp/ecflow-packaging-stage.1l0fbCiRi7/ecflow-build-sandbox/libs/attribute/',
-                '/tmp/ecflow-packaging-stage.1l0fbCiRi7/ecflow-build-sandbox/libs/node/',
-                '/tmp/ecflow-packaging-stage.1l0fbCiRi7/ecflow-build-sandbox/libs/base/',
-                '/tmp/ecflow-packaging-stage.1l0fbCiRi7/ecflow-build-sandbox/libs/simulator/',
-                '/tmp/ecflow-packaging-stage.1l0fbCiRi7/ecflow-build-sandbox/libs/client/',
+library_dirs = ['/tmp/ecflow-packaging-stage.TMI7sHUj3L/ecflow-build-sandbox/libs/core',
+                '/tmp/ecflow-packaging-stage.TMI7sHUj3L/ecflow-build-sandbox/libs/attribute/',
+                '/tmp/ecflow-packaging-stage.TMI7sHUj3L/ecflow-build-sandbox/libs/node/',
+                '/tmp/ecflow-packaging-stage.TMI7sHUj3L/ecflow-build-sandbox/libs/base/',
+                '/tmp/ecflow-packaging-stage.TMI7sHUj3L/ecflow-build-sandbox/libs/simulator/',
+                '/tmp/ecflow-packaging-stage.TMI7sHUj3L/ecflow-build-sandbox/libs/client/',
                 boost_lib_dir,
                ]
 
@@ -88,16 +88,16 @@ extra_link_args = []
 #   lib/python2.7/site-packages/ecflow/ecflow.so
 #                                     __init__.py               
 setup( name='ecflow', 
-       version='5.14.1', 
+       version='5.15.0', 
        author      = 'ECMWF',
        description = """ecflow Python interface""",
        packages = [ 'ecflow' ],
        url = 'https://confluence.ecmwf.int/display/ECFLOW/ecflow+home',
        license = 'Apache',
-       package_dir={'ecflow': '/tmp/ecflow-packaging-stage.1l0fbCiRi7/ecflow/libs/pyext/ecflow'},
+       package_dir={'ecflow': '/tmp/ecflow-packaging-stage.TMI7sHUj3L/ecflow/libs/pyext/ecflow'},
        ext_modules=[ Extension( 
                               'ecflow.ecflow', 
-                              glob.glob(os.path.join('/tmp/ecflow-packaging-stage.1l0fbCiRi7/ecflow/libs/pyext/src', '*.cpp')), 
+                              glob.glob(os.path.join('/tmp/ecflow-packaging-stage.TMI7sHUj3L/ecflow/libs/pyext/src', '*.cpp')), 
                               include_dirs=include_dirs, 
                               library_dirs=library_dirs, 
                               libraries=libraries,
