@@ -17,7 +17,7 @@
 #include "ServerTestHarness.hpp"
 #include "ecflow/attribute/QueueAttr.hpp"
 #include "ecflow/attribute/VerifyAttr.hpp"
-#include "ecflow/core/DurationTimer.hpp"
+#include "ecflow/core/Timer.hpp"
 #include "ecflow/node/Defs.hpp"
 #include "ecflow/node/Family.hpp"
 #include "ecflow/node/Suite.hpp"
