@@ -9,9 +9,8 @@
  */
 
 #include <iostream>
-#include <limits> // for std::numeric_limits<int>::max()
+#include <limits>
 
-#include <boost/date_time/posix_time/posix_time_types.hpp>
 #include <boost/test/unit_test.hpp>
 
 #include "ServerTestHarness.hpp"
@@ -20,18 +19,15 @@
 #include "ecflow/core/AssertTimer.hpp"
 #include "ecflow/core/Child.hpp"
 #include "ecflow/core/Converter.hpp"
-#include "ecflow/core/DurationTimer.hpp"
 #include "ecflow/core/Environment.hpp"
+#include "ecflow/core/Timer.hpp"
 #include "ecflow/node/Defs.hpp"
 #include "ecflow/node/Family.hpp"
 #include "ecflow/node/Suite.hpp"
 #include "ecflow/node/Task.hpp"
 #include "ecflow/test/scaffold/Naming.hpp"
 
-using namespace std;
 using namespace ecf;
-using namespace boost::gregorian;
-using namespace boost::posix_time;
 
 ///
 /// \note This is used to INVOKE a SINGLE test.
@@ -74,15 +70,16 @@ enum WaitType { SINGLE, ALL };
 static int timeout      = 32;
 static int NUM_OF_TASKS = 5;
 
-static std::string dump_tasks(const vector<Task*>& tasks) {
+static std::string dump_tasks(const std::vector<Task*>& tasks) {
     std::stringstream ss;
     ss << "     task status: no of tasks(" << tasks.size() << ")\n";
     for (const Task* task : tasks) {
         ss << "      " << task->absNodePath() << " " << NState::toString(task->state())
            << " passwd:" << task->jobsPassword() << " pid:" << task->process_or_remote_id()
            << " flag:" << task->get_flag().to_string();
-        if (task->state() == NState::ABORTED)
+        if (task->state() == NState::ABORTED) {
             ss << " " << task->abortedReason();
+        }
         ss << "\n";
     }
     ss << "\n";
@@ -92,7 +89,7 @@ static std::string dump_tasks(const vector<Task*>& tasks) {
 static std::string dump_task_status() {
     TestFixture::client().sync_local();
     defs_ptr defs = TestFixture::client().defs();
-    vector<Task*> tasks;
+    std::vector<Task*> tasks;
     defs->getAllTasks(tasks);
     return dump_tasks(tasks);
 }
@@ -108,18 +105,22 @@ static bool waitForTaskStates(WaitType num_of_tasks, NState::State state1, NStat
     std::string wait_type_str = (num_of_tasks == SINGLE) ? "SINGLE" : "ALL";
     if (ecf_debug_enabled) {
         if (num_of_tasks == SINGLE) {
-            if (state1 == state2)
+            if (state1 == state2) {
                 std::cout << "\n   Waiting for SINGLE task to reach state " << NState::toString(state1) << "\n";
-            else
+            }
+            else {
                 std::cout << "\n   Waiting for SINGLE task to reach state " << NState::toString(state1) << " || "
                           << NState::toString(state2) << "\n";
+            }
         }
         else {
-            if (state1 == state2)
+            if (state1 == state2) {
                 std::cout << "\n   Waiting for ALL tasks to reach state " << NState::toString(state1) << "\n";
-            else
+            }
+            else {
                 std::cout << "\n   Waiting for ALL tasks to reach state " << NState::toString(state1) << " || "
                           << NState::toString(state2) << "\n";
+            }
         }
     }
     AssertTimer assertTimer(max_time_to_wait, false); // Bomb out after n seconds, fall back if test fail
@@ -128,18 +129,20 @@ static bool waitForTaskStates(WaitType num_of_tasks, NState::State state1, NStat
                               "waitForTaskStates:*error* sync_local failed should return 0\n"
                                   << TestFixture::client().errorMsg());
         defs_ptr defs = TestFixture::client().defs();
-        vector<Task*> tasks;
+        std::vector<Task*> tasks;
         defs->getAllTasks(tasks);
         if (num_of_tasks == SINGLE) {
             for (Task* task : tasks) {
                 if (task->state() == state1 || task->state() == state2) {
                     if (ecf_debug_enabled) {
-                        if (task->state() == state1)
+                        if (task->state() == state1) {
                             std::cout << "    Found at least one Task with state " << NState::toString(state1)
                                       << " returning\n";
-                        if (state1 != state2 && task->state() == state2)
+                        }
+                        if (state1 != state2 && task->state() == state2) {
                             std::cout << "    Found at least one Task with state " << NState::toString(state2)
                                       << " returning\n";
+                        }
                         dump_zombies();
                     }
                     return true;
@@ -149,17 +152,20 @@ static bool waitForTaskStates(WaitType num_of_tasks, NState::State state1, NStat
         else {
             size_t count = 0;
             for (Task* task : tasks) {
-                if (task->state() == state1 || task->state() == state2)
+                if (task->state() == state1 || task->state() == state2) {
                     count++;
+                }
             }
             if (count == tasks.size()) {
                 if (ecf_debug_enabled) {
-                    if (state2 == state1)
+                    if (state2 == state1) {
                         std::cout << "    All tasks(" << tasks.size() << ") have reached state "
                                   << NState::toString(state1) << " returning\n";
-                    else
+                    }
+                    else {
                         std::cout << "    All tasks(" << tasks.size() << ") have reached state "
                                   << NState::toString(state1) << " || " << NState::toString(state2) << " returning\n";
+                    }
                     dump_tasks(tasks);
                     dump_zombies();
                 }
@@ -188,9 +194,10 @@ static bool waitForTaskState(WaitType wait_type, NState::State state1, int max_t
 }
 
 static bool waitForZombieCreation(size_t no_of_zombies, int max_time_to_wait) {
-    if (ecf_debug_enabled)
+    if (ecf_debug_enabled) {
         std::cout << "\n   Waiting for " << no_of_zombies
                   << " zombies to be created. max_time_to_wait:" << max_time_to_wait << "s\n";
+    }
 
     AssertTimer assertTimer(max_time_to_wait, false); // Bomb out after n seconds, fall back if test fail
     while (1) {
@@ -233,8 +240,9 @@ static bool waitForZombieCreation(size_t no_of_zombies, int max_time_to_wait) {
 static void remove_stale_zombies() {
     // Remove those zombies that have only *ZERO* calls hence PID is empty
     // There is no associated process/child command that has updated the zombie
-    if (ecf_debug_enabled)
-        cout << "\n   remove_stale_zombies\n";
+    if (ecf_debug_enabled) {
+        std::cout << "\n   remove_stale_zombies\n";
+    }
 
     BOOST_REQUIRE_MESSAGE(TestFixture::client().zombieGet() == 0,
                           "*error* zombieGet failed should return 0\n"
@@ -242,18 +250,19 @@ static void remove_stale_zombies() {
     std::vector<Zombie> zombies = TestFixture::client().server_reply().zombies();
     for (const Zombie& z : zombies) {
         if (z.process_or_remote_id().empty()) {
-            cout << "\n      **** removing_stale_zombies ***** " << z << "\n";
-            cout << "        Typically happens when a submitted job, never creates a process ?\n";
-            cout << "        Since the process never communicated back, the pid is empty.\n";
+            std::cout << "\n      **** removing_stale_zombies ***** " << z << "\n";
+            std::cout << "        Typically happens when a submitted job, never creates a process ?\n";
+            std::cout << "        Since the process never communicated back, the pid is empty.\n";
             TestFixture::client().zombieRemove(z);
         }
     }
 }
 
 static void wait_for_zombies_of_type(Child::ZombieType zt, int no_of_tasks, int max_time_to_wait) {
-    if (ecf_debug_enabled)
-        cout << "\n   wait_for_zombies_of_type: " << Child::to_string(zt) << " no_of_tasks:" << no_of_tasks
-             << " max_time_to_wait:" << max_time_to_wait << "s\n";
+    if (ecf_debug_enabled) {
+        std::cout << "\n   wait_for_zombies_of_type: " << Child::to_string(zt) << " no_of_tasks:" << no_of_tasks
+                  << " max_time_to_wait:" << max_time_to_wait << "s\n";
+    }
 
     std::vector<Zombie> zombies;
     AssertTimer assertTimer(max_time_to_wait, false); // Bomb out after n seconds, fall back if test fail
@@ -264,11 +273,13 @@ static void wait_for_zombies_of_type(Child::ZombieType zt, int no_of_tasks, int
         zombies           = TestFixture::client().server_reply().zombies();
         int no_of_zombies = 0;
         for (const Zombie& z : zombies) {
-            if (z.type() == zt)
+            if (z.type() == zt) {
                 no_of_zombies++;
+            }
         }
-        if (no_of_zombies >= no_of_tasks)
+        if (no_of_zombies >= no_of_tasks) {
             break;
+        }
 
         // make sure test does not take too long.
         if (assertTimer.duration() >= assertTimer.timeConstraint()) {
@@ -285,14 +296,15 @@ static void wait_for_zombies_of_type(Child::ZombieType zt, int no_of_tasks, int
     }
 
     if (ecf_debug_enabled) {
-        cout << Zombie::pretty_print(zombies, 6) << "\n";
-        cout << dump_task_status();
+        std::cout << Zombie::pretty_print(zombies, 6) << "\n";
+        std::cout << dump_task_status();
     }
 }
 
 static void check_expected_no_of_zombies(size_t expected) {
-    if (ecf_debug_enabled)
-        cout << "   check_expected_no_of_zombies: " << expected << "\n";
+    if (ecf_debug_enabled) {
+        std::cout << "   check_expected_no_of_zombies: " << expected << "\n";
+    }
     TestFixture::client().zombieGet();
     std::vector<Zombie> zombies = TestFixture::client().server_reply().zombies();
 
@@ -304,8 +316,9 @@ static void check_expected_no_of_zombies(size_t expected) {
 }
 
 static void check_expected_no_of_zombies_range(size_t min_expected, size_t max_expected) {
-    if (ecf_debug_enabled)
-        cout << "   check_expected_no_of_zombies_range: min:" << min_expected << " max:" << max_expected << "\n";
+    if (ecf_debug_enabled) {
+        std::cout << "   check_expected_no_of_zombies_range: min:" << min_expected << " max:" << max_expected << "\n";
+    }
     TestFixture::client().zombieGet();
     std::vector<Zombie> zombies = TestFixture::client().server_reply().zombies();
 
@@ -330,16 +343,18 @@ static int check_at_least_one_zombie() {
 }
 
 static bool wait_for_zombie_termination(int max_time_to_wait) {
-    if (ecf_debug_enabled)
+    if (ecf_debug_enabled) {
         std::cout << "\n   wait_for_zombie_termination: max_time_to_wait:" << max_time_to_wait << "\n";
+    }
 
     AssertTimer assertTimer(max_time_to_wait, false); // Bomb out after n seconds, fall back if test fail
     while (1) {
         TestFixture::client().zombieGet();
         std::vector<Zombie> zombies = TestFixture::client().server_reply().zombies();
         if (zombies.empty()) {
-            if (ecf_debug_enabled)
-                cout << "      zombies empty. Waited for " << assertTimer.duration() << "s returning\n";
+            if (ecf_debug_enabled) {
+                std::cout << "      zombies empty. Waited for " << assertTimer.duration() << "s returning\n";
+            }
             break;
         }
 
@@ -362,13 +377,16 @@ static void wait_for_zombies_child_cmd(WaitType wait_type,
                                        bool do_delete = false) {
     if (ecf_debug_enabled) {
         std::cout << "\n   Waiting for ";
-        if (wait_type == SINGLE)
+        if (wait_type == SINGLE) {
             std::cout << "SINGLE";
-        else
+        }
+        else {
             std::cout << "ALL";
+        }
         std::cout << "  child (" << Child::to_string(child_cmd) << ") cmd; ";
-        if (do_delete)
+        if (do_delete) {
             std::cout << " then DELETE zombies ";
+        }
         std::cout << "=============================================================================================\n";
     }
 
@@ -377,19 +395,22 @@ static void wait_for_zombies_child_cmd(WaitType wait_type,
     while (1) {
         TestFixture::client().zombieGet();
         std::vector<Zombie> zombies = TestFixture::client().server_reply().zombies();
-        if (ecf_debug_enabled)
+        if (ecf_debug_enabled) {
             std::cout << "    Get zombies returned " << zombies.size() << "\n";
+        }
 
         if (zombies.empty() && child_type_found && do_delete) {
-            if (ecf_debug_enabled)
+            if (ecf_debug_enabled) {
                 std::cout << "   No zombies. (do_delete) was set returning\n";
+            }
             return;
         }
 
         size_t completed_zombies = 0;
         for (const Zombie& z : zombies) {
-            if (ecf_debug_enabled)
+            if (ecf_debug_enabled) {
                 std::cout << "   " << z << "\n";
+            }
             if (z.last_child_cmd() == child_cmd) {
                 child_type_found = true;
                 completed_zombies++;
@@ -411,8 +432,9 @@ static void wait_for_zombies_child_cmd(WaitType wait_type,
             }
             if (do_delete) {
                 for (const Zombie& z : zombies) {
-                    if (ecf_debug_enabled)
+                    if (ecf_debug_enabled) {
                         std::cout << "   deleteing " << z << "\n";
+                    }
                     TestFixture::client().zombieRemove(z);
                 }
             }
@@ -432,8 +454,9 @@ static void wait_for_zombies_child_cmd(WaitType wait_type,
 }
 
 static void wait_for_no_zombies(int max_time_to_wait) {
-    if (ecf_debug_enabled)
+    if (ecf_debug_enabled) {
         std::cout << "\n   wait_for_no_zombies, for " << max_time_to_wait << "s\n";
+    }
 
     AssertTimer assertTimer(max_time_to_wait, false); // Bomb out after n seconds, fall back if test fail
     while (1) {
@@ -441,12 +464,14 @@ static void wait_for_no_zombies(int max_time_to_wait) {
         std::vector<Zombie> zombies = TestFixture::client().server_reply().zombies();
         if (ecf_debug_enabled) {
             std::cout << "      Get zombies returned " << zombies.size() << "\n";
-            if (!zombies.empty())
+            if (!zombies.empty()) {
                 std::cout << Zombie::pretty_print(zombies, 6) << "\n";
+            }
         }
         if (zombies.empty()) {
-            if (ecf_debug_enabled)
+            if (ecf_debug_enabled) {
                 std::cout << "      returning after " << assertTimer.duration() << "s\n";
+            }
             return;
         }
 
@@ -485,8 +510,9 @@ create_and_start_test(Defs& theDefs, const std::string& suite_name, const std::s
             ZombieCtrlAction::REMOVE, TestFixture::client().server_reply().zombies().size(), timeout);
     }
 
-    if (ecf_debug_enabled)
+    if (ecf_debug_enabled) {
         std::cout << "   creating server test harness\n";
+    }
 
     // The test harness will create corresponding directory structure & default ecf file
     ServerTestHarness serverTestHarness;
@@ -506,18 +532,21 @@ create_and_start_test(Defs& theDefs, const std::string& suite_name, const std::s
     size_t number_submitted_or_active = 0;
     TestFixture::client().sync_local();
     defs_ptr defs = TestFixture::client().defs();
-    vector<Task*> tasks;
+    std::vector<Task*> tasks;
     defs->getAllTasks(tasks);
     for (const auto& task : tasks) {
-        if (task->state() == NState::SUBMITTED || task->state() == NState::ACTIVE)
+        if (task->state() == NState::SUBMITTED || task->state() == NState::ACTIVE) {
             number_submitted_or_active++;
+        }
     }
-    if (ecf_debug_enabled)
+    if (ecf_debug_enabled) {
         std::cout << "   found " << number_submitted_or_active << " in submitted or active state\n";
+    }
 
     if (create_zombies_with == "delete") {
-        if (ecf_debug_enabled)
+        if (ecf_debug_enabled) {
             std::cout << "   create USER zombies by deleting all the nodes in the server\n";
+        }
         TestFixture::client().delete_all(true /* force */);
     }
     else if (create_zombies_with == "begin") {
@@ -556,8 +585,9 @@ create_and_start_test(Defs& theDefs, const std::string& suite_name, const std::s
         std::vector<Task*> tasks;
         theDefs.getAllTasks(tasks);
         std::vector<std::string> paths;
-        for (auto task : tasks)
+        for (auto task : tasks) {
             paths.emplace_back(task->absNodePath());
+        }
 
         TestFixture::client().set_throw_on_error(false);
         if (TestFixture::client().force(paths, "queued") == 1) {
@@ -567,15 +597,17 @@ create_and_start_test(Defs& theDefs, const std::string& suite_name, const std::s
     }
     else if (create_zombies_with == "complete") {
 
-        if (ecf_debug_enabled)
+        if (ecf_debug_enabled) {
             std::cout << "   create USER zombies by calling complete\n";
+        }
         std::string path = "/" + suite_name;
         TestFixture::client().force(path, "complete", true /*recursive*/);
     }
     else if (create_zombies_with == "aborted") {
 
-        if (ecf_debug_enabled)
+        if (ecf_debug_enabled) {
             std::cout << "   create USER zombies by calling abort\n";
+        }
         std::string path = "/" + suite_name;
         TestFixture::client().force(path, "aborted", true /*recursive*/);
     }
@@ -615,7 +647,7 @@ create_and_start_test(Defs& theDefs, const std::string& suite_name, const std::s
         }
     }
     if (ecf_debug_enabled) {
-        cout << dump_task_status();
+        std::cout << dump_task_status();
     }
 }
 
@@ -632,8 +664,9 @@ static void create_and_start_test(const std::string& suite_name,
     if (add_delay_before_init) {
         suite_ptr suite = theDefs.findSuite(suite_name);
         suite->add_variable("ADD_DELAY_BEFORE_INIT", "sleep 1"); // add delay before --init
-        if (ecf_debug_enabled)
+        if (ecf_debug_enabled) {
             std::cout << "   adding a delay of 1 second before --init is called\n";
+        }
     }
     create_and_start_test(theDefs, suite_name, create_zombies_with);
 }
@@ -653,11 +686,13 @@ BOOST_AUTO_TEST_CASE(enable_debug_for_ECF_TRY_NO_Greater_than_one) {
 BOOST_AUTO_TEST_CASE(test_path_zombie_creation) {
     ECF_NAME_THIS_TEST();
 
-    if (ecf_debug_enabled)
+    if (ecf_debug_enabled) {
         std::cout << "\n\n=============================================================================\n";
+    }
     DurationTimer timer;
-    if (ecf_debug_enabled)
-        cout << "\n";
+    if (ecf_debug_enabled) {
+        std::cout << "\n";
+    }
     TestClean clean_at_start_and_end;
 
     // This command creates user zombies up front, these may not have a pid, if task in submitted state
@@ -691,7 +726,7 @@ BOOST_AUTO_TEST_CASE(test_path_zombie_creation) {
     // The fob should have forced removal of zombies, in the server. when the COMPLETE child command was recieved
     check_expected_no_of_zombies(0);
 
-    cout << timer.duration() << "s\n";
+    std::cout << timer.duration() << "s\n";
 }
 #endif
 
@@ -699,11 +734,13 @@ BOOST_AUTO_TEST_CASE(test_path_zombie_creation) {
 BOOST_AUTO_TEST_CASE(test_user_zombies_for_delete_fob) {
     ECF_NAME_THIS_TEST();
 
-    if (ecf_debug_enabled)
+    if (ecf_debug_enabled) {
         std::cout << "\n\n=============================================================================\n";
+    }
     DurationTimer timer;
-    if (ecf_debug_enabled)
-        cout << "\n";
+    if (ecf_debug_enabled) {
+        std::cout << "\n";
+    }
     TestClean clean_at_start_and_end;
 
     // This command creates user zombies up front, these may not have a pid, if task in submitted state
@@ -730,7 +767,7 @@ BOOST_AUTO_TEST_CASE(test_user_zombies_for_delete_fob) {
     // The fob should have forced removal of zombies, in the server. when the COMPLETE child command was recieved
     check_expected_no_of_zombies(0);
 
-    cout << timer.duration() << "s\n";
+    std::cout << timer.duration() << "s\n";
 }
 #endif
 
@@ -738,11 +775,13 @@ BOOST_AUTO_TEST_CASE(test_user_zombies_for_delete_fob) {
 BOOST_AUTO_TEST_CASE(test_user_zombies_for_delete_fail) {
     ECF_NAME_THIS_TEST();
 
-    if (ecf_debug_enabled)
+    if (ecf_debug_enabled) {
         std::cout << "\n\n=============================================================================\n";
+    }
     DurationTimer timer;
-    if (ecf_debug_enabled)
-        cout << "\n";
+    if (ecf_debug_enabled) {
+        std::cout << "\n";
+    }
     TestClean clean_at_start_and_end;
 
     // This command creates user zombies up front, these may not have a pid, if task in submitted state
@@ -761,7 +800,7 @@ BOOST_AUTO_TEST_CASE(test_user_zombies_for_delete_fail) {
     wait_for_zombies_child_cmd(ALL, ecf::Child::ABORT, timeout, true /* delete */);
 
     check_expected_no_of_zombies(0);
-    cout << timer.duration() << "s\n";
+    std::cout << timer.duration() << "s\n";
 }
 #endif
 
@@ -771,11 +810,13 @@ BOOST_AUTO_TEST_CASE(test_user_zombies_for_delete_fail) {
 BOOST_AUTO_TEST_CASE(test_user_zombies_for_begin) {
     ECF_NAME_THIS_TEST();
 
-    if (ecf_debug_enabled)
+    if (ecf_debug_enabled) {
         std::cout << "\n\n=============================================================================\n";
+    }
     DurationTimer timer;
-    if (ecf_debug_enabled)
-        cout << "\n";
+    if (ecf_debug_enabled) {
+        std::cout << "\n";
+    }
     TestClean clean_at_start_and_end;
 
     // This command creates user zombies up front, these may not have a pid, if task in submitted state
@@ -808,7 +849,7 @@ BOOST_AUTO_TEST_CASE(test_user_zombies_for_begin) {
     // The fob should have forced removal of zombies, in the server. when the COMPLETE child command was recieved
     check_expected_no_of_zombies(0);
 
-    cout << timer.duration() << "s\n";
+    std::cout << timer.duration() << "s\n";
 }
 #endif
 
@@ -816,12 +857,14 @@ BOOST_AUTO_TEST_CASE(test_user_zombies_for_begin) {
 BOOST_AUTO_TEST_CASE(test_zombies_attr) {
     ECF_NAME_THIS_TEST();
 
-    if (ecf_debug_enabled)
+    if (ecf_debug_enabled) {
         std::cout << "\n\n=============================================================================\n";
+    }
     DurationTimer timer;
     std::string suite_name = "test_zombies_attr";
-    if (ecf_debug_enabled)
-        cout << "\n";
+    if (ecf_debug_enabled) {
+        std::cout << "\n";
+    }
     TestClean clean_at_start_and_end;
 
     // This command creates user zombies up front, these may not have a pid, if task in submitted state
@@ -837,8 +880,9 @@ BOOST_AUTO_TEST_CASE(test_zombies_attr) {
     check_at_least_one_zombie();
 
     /// *** Fobbing will not change state of the node tree ****
-    if (ecf_debug_enabled)
+    if (ecf_debug_enabled) {
         std::cout << "   Add a zombie attribute 'user:fob::' to the suite, which fobs all child commands\n";
+    }
     TestFixture::client().alter("/" + suite_name, "add", "zombie", "user:fob::");
 
     // Fobbing causes auto deletion of zombies, when the Child complete is reached
@@ -849,7 +893,7 @@ BOOST_AUTO_TEST_CASE(test_zombies_attr) {
     // The fob should have forced removal of zombies, in the server. when the COMPLETE child command was recieved
     check_expected_no_of_zombies(0);
 
-    cout << timer.duration() << "s\n";
+    std::cout << timer.duration() << "s\n";
 }
 #endif
 
@@ -857,12 +901,14 @@ BOOST_AUTO_TEST_CASE(test_zombies_attr) {
 BOOST_AUTO_TEST_CASE(test_user_zombies_for_adopt) {
     ECF_NAME_THIS_TEST();
 
-    if (ecf_debug_enabled)
+    if (ecf_debug_enabled) {
         std::cout << "\n\n=============================================================================\n";
+    }
     DurationTimer timer;
     std::string suite_name = "test_user_zombies_for_adopt";
-    if (ecf_debug_enabled)
-        cout << "\n";
+    if (ecf_debug_enabled) {
+        std::cout << "\n";
+    }
     TestClean clean_at_start_and_end;
 
     // This command creates user zombies up front, these may not have a pid, if task in submitted state
@@ -879,8 +925,9 @@ BOOST_AUTO_TEST_CASE(test_user_zombies_for_adopt) {
     /// Adopt all the zombies. This will UNBLOCK the child commands allowing them to finish
     /// This test below fail on AIX, its too fast , task's may already be adopted and hence don't fail
     int no_of_adopted_zombied = ZombieUtil::do_zombie_user_action(ZombieCtrlAction::ADOPT, NUM_OF_TASKS, timeout);
-    if (ecf_debug_enabled)
-        cout << "   found " << no_of_adopted_zombied << " zombies for adoption\n";
+    if (ecf_debug_enabled) {
+        std::cout << "   found " << no_of_adopted_zombied << " zombies for adoption\n";
+    }
 
     /// The blocked zombies are free, start with blocked init command
     (void)waitForTaskState(SINGLE, NState::ACTIVE, timeout);
@@ -894,7 +941,7 @@ BOOST_AUTO_TEST_CASE(test_user_zombies_for_adopt) {
     // After adoption the zombies should be removed
     check_expected_no_of_zombies(0);
 
-    cout << timer.duration() << "s\n";
+    std::cout << timer.duration() << "s\n";
 }
 #endif
 
@@ -903,8 +950,9 @@ BOOST_AUTO_TEST_CASE(test_zombies_attr_for_adopt) {
     std::string suite_name = "test_zombies_attr_for_adopt";
     ECF_NAME_THIS_TEST(<< ", using suite: " << suite_name);
 
-    if (ecf_debug_enabled)
+    if (ecf_debug_enabled) {
         std::cout << "\n\n=============================================================================\n";
+    }
     DurationTimer timer;
     TestClean clean_at_start_and_end;
 
@@ -918,13 +966,15 @@ BOOST_AUTO_TEST_CASE(test_zombies_attr_for_adopt) {
     // expected 5 zombies, ie because we have NUM_OF_TASKS tasks. These should all be blocking
     check_at_least_one_zombie();
 
-    if (ecf_debug_enabled)
+    if (ecf_debug_enabled) {
         std::cout << "   Add a zombie attribute 'user:adopt::' to the suite, which *ADOPTS* all zombies allowing them "
                      "to complete\n";
+    }
     TestFixture::client().alter("/" + suite_name, "add", "zombie", "user:adopt::");
 
-    if (ecf_debug_enabled)
+    if (ecf_debug_enabled) {
         dump_zombies();
+    }
 
     /// The blocked zombies are free, start with blocked init command
     /// This may fail on AIX, its too fast , task's may already be complete, dont fail
@@ -939,7 +989,7 @@ BOOST_AUTO_TEST_CASE(test_zombies_attr_for_adopt) {
     // After adoption the zombies should be removed
     check_expected_no_of_zombies(0);
 
-    cout << timer.duration() << "s\n";
+    std::cout << timer.duration() << "s\n";
 }
 #endif
 
@@ -948,8 +998,9 @@ BOOST_AUTO_TEST_CASE(test_user_zombie_creation_via_complete) {
     std::string suite_name = "test_zombies_attr_for_adopt";
     ECF_NAME_THIS_TEST(<< ", using suite: " << suite_name);
 
-    if (ecf_debug_enabled)
+    if (ecf_debug_enabled) {
         std::cout << "\n\n=============================================================================\n";
+    }
     DurationTimer timer;
     TestClean clean_at_start_and_end;
 
@@ -965,7 +1016,7 @@ BOOST_AUTO_TEST_CASE(test_user_zombie_creation_via_complete) {
     // Wait for zombies to complete, they should get removed automatically
     wait_for_no_zombies(timeout);
 
-    cout << timer.duration() << "s\n";
+    std::cout << timer.duration() << "s\n";
 }
 #endif
 
@@ -974,8 +1025,9 @@ BOOST_AUTO_TEST_CASE(test_user_zombie_creation_via_abort) {
     std::string suite_name = "test_user_zombie_creation_via_abort";
     ECF_NAME_THIS_TEST(<< ", using suite: " << suite_name);
 
-    if (ecf_debug_enabled)
+    if (ecf_debug_enabled) {
         std::cout << "\n\n=============================================================================\n";
+    }
     DurationTimer timer;
     TestClean clean_at_start_and_end;
 
@@ -991,7 +1043,7 @@ BOOST_AUTO_TEST_CASE(test_user_zombie_creation_via_abort) {
     // Wait for zombies to complete, they should get removed automatically
     wait_for_no_zombies(timeout);
 
-    cout << timer.duration() << "s\n";
+    std::cout << timer.duration() << "s\n";
 }
 #endif
 
@@ -1000,8 +1052,9 @@ BOOST_AUTO_TEST_CASE(test_zombie_inheritance) {
     std::string suite_name = "test_zombie_inheritance";
     ECF_NAME_THIS_TEST(<< ", using suite: " << suite_name);
 
-    if (ecf_debug_enabled)
+    if (ecf_debug_enabled) {
         std::cout << "\n\n=============================================================================\n";
+    }
     DurationTimer timer;
     TestClean clean_at_start_and_end;
 
@@ -1037,33 +1090,37 @@ BOOST_AUTO_TEST_CASE(test_zombie_inheritance) {
     // Wait for zombies to complete, they should get removed automatically
     wait_for_no_zombies(timeout);
 
-    cout << timer.duration() << "s\n";
+    std::cout << timer.duration() << "s\n";
 }
 #endif
 
 #ifdef DO_TEST11
 static int wait_for_killed_zombies(int no_of_tasks, int max_time_to_wait) {
-    if (ecf_debug_enabled)
+    if (ecf_debug_enabled) {
         std::cout << "\n   wait_for_killed_zombies\n";
+    }
     AssertTimer assertTimer(max_time_to_wait, false); // Bomb out after n seconds, fall back if test fail
     while (1) {
         int killed = 0;
         TestFixture::client().zombieGet();
         std::vector<Zombie> zombies = TestFixture::client().server_reply().zombies();
         for (const Zombie& z : zombies) {
-            if (z.kill())
+            if (z.kill()) {
                 killed++;
+            }
         }
-        if (ecf_debug_enabled)
+        if (ecf_debug_enabled) {
             std::cout << "   found " << killed << " killed zombies\n";
+        }
 
-        if (killed == no_of_tasks)
+        if (killed == no_of_tasks) {
             return killed;
+        }
 
         if (assertTimer.duration() >= assertTimer.timeConstraint()) {
-            cout << "   wait_for_killed_zombies Test wait " << assertTimer.duration()
-                 << " taking longer than time constraint of " << assertTimer.timeConstraint() << " breaking out\n"
-                 << Zombie::pretty_print(zombies, 6) << "\n";
+            std::cout << "   wait_for_killed_zombies Test wait " << assertTimer.duration()
+                      << " taking longer than time constraint of " << assertTimer.timeConstraint() << " breaking out\n"
+                      << Zombie::pretty_print(zombies, 6) << "\n";
             return killed;
         }
         sleep(2);
@@ -1075,8 +1132,9 @@ BOOST_AUTO_TEST_CASE(test_zombie_kill) {
     std::string suite_name = "test_zombie_kill";
     ECF_NAME_THIS_TEST(<< ", using suite: " << suite_name);
 
-    if (ecf_debug_enabled)
+    if (ecf_debug_enabled) {
         std::cout << "\n\n=============================================================================\n";
+    }
     DurationTimer timer;
     TestClean clean_at_start_and_end;
 
@@ -1104,18 +1162,22 @@ BOOST_AUTO_TEST_CASE(test_zombie_kill) {
             TestFixture::client().zombieGet();
             std::vector<Zombie> zombies = TestFixture::client().server_reply().zombies();
             for (const Zombie& z : zombies) {
-                if (z.last_child_cmd() == ecf::Child::ABORT)
+                if (z.last_child_cmd() == ecf::Child::ABORT) {
                     aborted++;
-                if (z.last_child_cmd() == ecf::Child::COMPLETE)
+                }
+                if (z.last_child_cmd() == ecf::Child::COMPLETE) {
                     completed++;
+                }
             }
-            if (aborted + completed == NUM_OF_TASKS)
+            if (aborted + completed == NUM_OF_TASKS) {
                 break;
+            }
             if (assertTimer.duration() >= assertTimer.timeConstraint()) {
-                cout << "   wait for for abort:  found " << aborted + completed
-                     << " aborted & completed tasks. Test wait " << assertTimer.duration()
-                     << " taking longer than time constraint of " << assertTimer.timeConstraint() << " breaking out\n"
-                     << Zombie::pretty_print(zombies, 6) << "\n";
+                std::cout << "   wait for for abort:  found " << aborted + completed
+                          << " aborted & completed tasks. Test wait " << assertTimer.duration()
+                          << " taking longer than time constraint of " << assertTimer.timeConstraint()
+                          << " breaking out\n"
+                          << Zombie::pretty_print(zombies, 6) << "\n";
                 break;
             }
             sleep(1);
@@ -1132,15 +1194,15 @@ BOOST_AUTO_TEST_CASE(test_zombie_kill) {
                 if (z.block()) { // something went wrong, fob so don't leave process hanging
                     TestFixture::client().zombieFob(z);
                     task_became_blocked = true;
-                    cout << "Zombies blocking ?? " << z << "\n";
+                    std::cout << "Zombies blocking ?? " << z << "\n";
                 }
             }
             if (assertTimer.duration() >= assertTimer.timeConstraint()) {
                 if (task_became_blocked) {
-                    cout << "   Task became blocked, fobing" << assertTimer.duration()
-                         << " taking longer than time constraint of " << assertTimer.timeConstraint()
-                         << " breaking out\n"
-                         << Zombie::pretty_print(zombies, 6) << "\n";
+                    std::cout << "   Task became blocked, fobing" << assertTimer.duration()
+                              << " taking longer than time constraint of " << assertTimer.timeConstraint()
+                              << " breaking out\n"
+                              << Zombie::pretty_print(zombies, 6) << "\n";
                 }
                 break;
             }
@@ -1153,7 +1215,7 @@ BOOST_AUTO_TEST_CASE(test_zombie_kill) {
 
     wait_for_no_zombies(timeout);
 
-    cout << timer.duration() << "s\n";
+    std::cout << timer.duration() << "s\n";
 }
 #endif
 
@@ -1161,7 +1223,7 @@ BOOST_AUTO_TEST_CASE(test_zombie_kill) {
 
 static void remove_all_user_zombies() {
     if (ecf_debug_enabled) {
-        cout << "\n   remove_all_user_zombies\n";
+        std::cout << "\n   remove_all_user_zombies\n";
         dump_zombies();
     }
 
@@ -1178,22 +1240,24 @@ static void remove_all_user_zombies() {
         }
         // make sure test does not take too long.
         if (assertTimer.duration() >= assertTimer.timeConstraint()) {
-            cout << "      removed " << removed_count
-                 << " user zombies. Quit waiting, to remove all zombies of type USER\n";
-            cout << Zombie::pretty_print(zombies, 6);
+            std::cout << "      removed " << removed_count
+                      << " user zombies. Quit waiting, to remove all zombies of type USER\n";
+            std::cout << Zombie::pretty_print(zombies, 6);
             return;
         }
         sleep(1);
     }
-    if (ecf_debug_enabled)
+    if (ecf_debug_enabled) {
         dump_zombies();
+    }
 }
 BOOST_AUTO_TEST_CASE(test_ecf_zombie_type_creation) {
     std::string suite_name = "test_ecf_zombie_type_creation";
     ECF_NAME_THIS_TEST(<< ", using suite: " << suite_name);
 
-    if (ecf_debug_enabled)
+    if (ecf_debug_enabled) {
         std::cout << "\n\n=============================================================================\n";
+    }
     DurationTimer timer;
     TestClean clean_at_start_and_end;
 
@@ -1224,7 +1288,7 @@ BOOST_AUTO_TEST_CASE(test_ecf_zombie_type_creation) {
     // The fob should have forced removal of zombies, in the server. when the COMPLETE child command was received
     check_expected_no_of_zombies(0);
 
-    cout << timer.duration() << "s\n";
+    std::cout << timer.duration() << "s\n";
 }
 #endif
 
